@@ -94,9 +94,14 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
     cnt_effect_vid=0
     introPath = None
     outroPath = None
-
+    firstImageOrVideoBG=[] #purpose for loop lyric outro
+    indexVidBG=0
     #check if videos are compilation
     for comp in arr_comps:
+        if indexVidBG < 5 and  (comp.type == "video" or comp.type == "image"):
+            firstImageOrVideoBG.append(comp)
+            indexVidBG+=1
+
         if comp.type == "lyric":
             is_lyric = True
             is_lyric_outro = comp.is_lyric_outro
@@ -105,6 +110,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
                 lyric_outro_repeat = comp.lyric_outro_repeat
         if comp.type == "compilation":
             is_compilation = True
+            #test
             audio_compilation_path = comp.get_audio()
 
     for comp in arr_comps:
@@ -216,7 +222,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
     duration_f = final_vid.duration
     final_vid.close()
     if is_lyric_outro:
-        lyricOutroPath = create_lyric_outro(deezer_artist_id, lyric_outro_repeat, arr_composite_no_intro)
+        lyricOutroPath = create_lyric_outro(deezer_artist_id, lyric_outro_repeat, firstImageOrVideoBG)
         path_video = merge_intro_outro(path_video, None, lyricOutroPath)
     path_video = merge_intro_outro(path_video, introPath, outroPath)
     for comp in arr_comps:
